package com.om.service.impl;

import cn.hutool.core.bean.BeanUtil;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.om.entity.dto.AppDTO;
import com.om.entity.dto.GuidDTO;
import com.om.entity.po.Apps;
import com.om.entity.po.AppsClients;
import com.om.entity.po.AppsDesc;
import com.om.entity.vo.AppUpdateVO;
import com.om.mapper.AppsMapper;
import com.om.service.IAppsClientsService;
import com.om.service.IAppsDescService;
import com.om.service.IAppsService;
import com.om.utils.AesUtil;
import com.om.utils.HuaweiObsUtil;
import com.om.utils.Result;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Comparator;
import java.util.List;
import java.util.Optional;
import java.util.function.Predicate;
import java.util.stream.Collectors;

/**
 * <p>
 * 软件应用表 服务实现类
 * </p>
 *
 * @author henry-ong
 * @since 2024-03-12
 */
@Service
public class AppsServiceImpl extends ServiceImpl<AppsMapper, Apps> implements IAppsService {
    private final AppsMapper appsMapper;

    public AppsServiceImpl(AppsMapper appsMapper) {
        this.appsMapper = appsMapper;
    }

    @Resource
    private IAppsClientsService appsClientsService;

    @Resource
    private IAppsDescService appsDescService;

    @Resource
    private HuaweiObsUtil obsUtil;

    @Override
    public Page<Apps> findApps(Page<Apps> objectPage, String code, String title) {
        return appsMapper.findApps(objectPage, code, title);
    }



    @Override
    public Result<AppUpdateVO> AppUpdate(AppDTO dto) {
        String version = dto.getVersion();
        String guid = dto.getGuid();
        GuidDTO guidDTO = AesUtil.getGuidDTOFromGuid(guid);
        String clientNum = guidDTO.getClientNum();
        String language = dto.getLanguage();

        List<Integer> appids = appsClientsService.lambdaQuery()
                .eq(AppsClients::getClientNum, clientNum)
                .list().stream().map(c -> c.getAppId()).collect(Collectors.toList());

        AppUpdateVO vo = new AppUpdateVO();
        if (!appids.isEmpty()){
            List<Apps> apps = this.listByIds(appids);
            if (!apps.isEmpty()){
                Apps apps1 = apps.stream().max(Comparator.comparing(Apps::getCreateTime)).get();
                vo.setFileName(apps1.getFileName());
                vo.setFileSize((long) (Double.valueOf(apps1.getFileSize()) *1024 * 1024));
                int lastIndexOf = apps1.getFileName().lastIndexOf(".");
                if (lastIndexOf != -1){
                    vo.setVersion(apps1.getFileName().substring(0, lastIndexOf));
                }

                AppsDesc appsDesc = appsDescService.lambdaQuery()
                        .eq(AppsDesc::getAppId, apps1.getId())
                        .eq(AppsDesc::getLanguage, language)
                        .one();
                if (BeanUtil.isNotEmpty(appsDesc)){
                    vo.setDescription(appsDesc.getDescription());
                }else {
                    vo.setDescription("");
                }
                String uploadUrl = obsUtil.getUploadUrl(apps1.getFileName(), "apps");
                vo.setUrl(uploadUrl);
                vo.setIsUpdate("1");
            }
        }

        return Result.ok(vo);
    }
}
