package com.om.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.om.entity.dto.DeviceQueryPageDTO;
import com.om.entity.po.Device;
import com.om.entity.po.DiagnosticMenu;
import com.om.entity.po.Repair;
import com.om.entity.vo.DeviceQueryPageVO;
import com.om.entity.vo.RepairQueryPageVO;
import com.om.mapper.DeviceMapper;
import com.om.service.IDeviceService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.om.utils.Result;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author bmmx
 * @since 2024-04-08
 */
@Service
public class DeviceServiceImpl extends ServiceImpl<DeviceMapper, Device> implements IDeviceService {

    @Override
    public Result<DeviceQueryPageVO> getPageList(DeviceQueryPageDTO dto) {
        Integer pageIndex = dto.getPageIndex();
        Integer pageSize = dto.getPageSize();
        String searchDeviceSn = dto.getSearchDeviceSn();
        String searchUsername = dto.getSearchUsername();
        String searchClientNum = dto.getSearchClientNum();

        Page<Device> page = this.lambdaQuery()
                .like(StringUtils.isNotBlank(searchDeviceSn), Device::getDeviceSn, searchDeviceSn)
                .like(StringUtils.isNotBlank(searchUsername), Device::getUsername, searchUsername)
                .like(StringUtils.isNotBlank(searchClientNum), Device::getClientNum, searchClientNum)
                .orderByDesc(Device::getCreateTime)
                .page(new Page<>(pageIndex, pageSize));

        DeviceQueryPageVO vo = new DeviceQueryPageVO();
        vo.setCurrent((int) page.getCurrent());
        vo.setSize((int) page.getSize());
        vo.setPages((int) page.getPages());
        vo.setTotal((int) page.getTotal());

        if (StringUtils.isNotBlank(searchDeviceSn) || StringUtils.isNotBlank(searchUsername) || StringUtils.isNotBlank(searchClientNum) ) {
            vo.setSearchCount(true);
        }

        List<Device> records = page.getRecords();
        if (records.isEmpty()){
            return Result.ok(vo);
        }
        vo.setRecords(records);
        return Result.ok(vo);
    }
}
